# Code of Conduct

This project follows a respectful and inclusive collaboration model.

Participants are expected to:

- Be respectful and professional
- Assume good intent
- Provide constructive feedback

Unacceptable behavior may result in moderation actions by repository maintainers.
